https://git.reactos.org/?p=reactos.git;a=commitdiff;h=7882b6cfe34885170ab0f…
commit 7882b6cfe34885170ab0fc34310805362fc2e12d
Author: Mark Jansen <mark.jansen(a)reactos.org>
AuthorDate: Sun Sep 23 19:27:02 2018 +0200
Commit: Mark Jansen <mark.jansen(a)reactos.org>
CommitDate: Sun Sep 23 20:03:08 2018 +0200
[SHELL32_APITEST] Speed up the CUserNotification test in the failure case.
---
modules/rostests/apitests/shell32/CUserNotification.cpp | 4 ++--
1 file changed, 2 insertions(+), 2 deletions(-)
diff --git a/modules/rostests/apitests/shell32/CUserNotification.cpp b/modules/rostests/apitests/shell32/CUserNotification.cpp
index acfd6023a8..ec40f42584 100644
--- a/modules/rostests/apitests/shell32/CUserNotification.cpp
+++ b/modules/rostests/apitests/shell32/CUserNotification.cpp
@@ -200,8 +200,8 @@ START_TEST(CUserNotification)
return;
}
- /* Wait a maximum of 1:30 for the thread to finish (the timeout tests take some time) */
- dwWait = WaitForSingleObject(hThread, 90 * 1000);
+ /* Wait a maximum of 60 seconds for the thread to finish (the timeout tests take some time) */
+ dwWait = WaitForSingleObject(hThread, 60 * 1000);
ok(dwWait == WAIT_OBJECT_0, "WaitForSingleObject returned %lu, expected WAIT_OBJECT_0\n", dwWait);
/* Cleanup and return */